@@ -57,6 +57,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.UUID;
 
 // 本样例展示在线语音合成CosyVoice（流式输入流式输出）使用方法
 // Android SDK 详细说明：https://help.aliyun.com/zh/model-studio/cosyvoice-android-sdk
@@ -488,7 +489,9 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
                     firstDataFlag = true;
                     Log.i(TAG, "start flow tts");
                     // 每个instance一个session
-                    if (Constants.NuiResultCode.SUCCESS == StartTts()) {
+                    UUID uuid = UUID.randomUUID();
+                    String taskId = uuid.toString();
+                    if (Constants.NuiResultCode.SUCCESS == StartTts(taskId)) {
                         is_started = true;
 
                         new Thread(new Runnable() {
@@ -536,7 +539,9 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
                     // 单次文本长度和多次累计文本长度均有限制，详细请查下以下文档。
                     // 文本长度限制: https://help.aliyun.com/zh/model-studio/cosyvoice-websocket-api
                     // 每个instance一个session
-                    int ret = AsyncPlayTts(ttsEditView.getText().toString());
+                    UUID uuid = UUID.randomUUID();
+                    String taskId = uuid.toString();
+                    int ret = AsyncPlayTts(ttsEditView.getText().toString(), taskId);
                     if (Constants.NuiResultCode.SUCCESS == ret) {
                         is_started = true;
                     }
@@ -796,13 +801,13 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
     public void onClick(View v) {
     }
 
-    private int StartTts() {
+    private int StartTts(String taskId) {
         int ret = stream_input_tts_instance.startStreamInputTts(new INativeStreamInputTtsCallback() {
             @Override
             public void onStreamInputTtsEventCallback(INativeStreamInputTtsCallback.StreamInputTtsEvent event,
                                                       String task_id, String session_id, int ret_code,
                                                       String error_msg, String timestamp, String all_response) {
-                Log.d(TAG, "stream input tts event(" + event + ") task id(" + task_id + ") retCode(" + ret_code + ") errMsg(" + error_msg + ")");
+                Log.d(TAG, "stream input tts event(" + event + ") session id(" + session_id + ") task id(" + task_id + ") retCode(" + ret_code + ") errMsg(" + error_msg + ")");
                 if (event == StreamInputTtsEvent.STREAM_INPUT_TTS_EVENT_SYNTHESIS_STARTED) {
                     Log.i(TAG, "STREAM_INPUT_TTS_EVENT_SYNTHESIS_STARTED");
                     startedTimestamp = System.currentTimeMillis();
@@ -954,7 +959,7 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
             public void onStreamInputTtsLogTrackCallback(Constants.LogLevel level, String log) {
 //                Log.i(TAG, "onStreamInputTtsLogTrackCallback log level:" + level + ", message -> " + log);
             }
-        }, genTicket(), genParameters(false), "",
+        }, genTicket(), genParameters(false), taskId,
                 Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_VERBOSE), true);
 
         if (Constants.NuiResultCode.SUCCESS != ret) {
@@ -968,12 +973,13 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
                 }
             });
         } else {
+            Log.i(TAG, "StartTts success with task_id:" + taskId);
             is_started = true;
         }
         return ret;
     }
 
-    private int AsyncPlayTts(String text) {
+    private int AsyncPlayTts(String text, String taskId) {
         int ret = stream_input_tts_instance.asyncPlayStreamInputTts(new INativeStreamInputTtsCallback() {
             @Override
             public void onStreamInputTtsEventCallback(INativeStreamInputTtsCallback.StreamInputTtsEvent event,
@@ -1128,7 +1134,7 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
             public void onStreamInputTtsLogTrackCallback(Constants.LogLevel level, String log) {
 //                Log.i(TAG, "onStreamInputTtsLogTrackCallback log level:" + level + ", message -> " + log);
             }
-        }, genTicket(), genParameters(true), text, "",
+        }, genTicket(), genParameters(true), text, taskId,
                 Constants.LogLevel.toInt(Constants.LogLevel.LOG_LEVEL_VERBOSE), true);
 
         if (Constants.NuiResultCode.SUCCESS != ret) {
@@ -1142,6 +1148,7 @@ public class DashCosyVoiceStreamTtsActivity extends Activity implements View.OnC
                 }
             });
         } else {
+            Log.i(TAG, "AsyncPlayTts success with task_id:" + taskId);
             is_started = true;
         }
         return ret;
