@@ -566,7 +566,7 @@ public class TtsLocalActivity extends Activity implements View.OnClickListener,
                     if (mEncodeType.equals("pcm") || mEncodeType.equals("wav")) {
                         mAudioTrack.setAudioData(data);
                     }
-                    Log.d(TAG, "write:" + data.length);
+//                    Log.d(TAG, "write:" + data.length);
                     try {
                         if (mSynthesisAudioFile != null) {
                             mSynthesisAudioFile.write(data);
@@ -586,7 +586,7 @@ public class TtsLocalActivity extends Activity implements View.OnClickListener,
             public void onTtsLogTrackCallback(Constants.LogLevel level, String log) {
                 Log.i(TAG, "onTtsLogTrackCallback local log level:" + level + ", message -> " + log);
             }
-        }, initParams, Constants.LogLevel.LOG_LEVEL_VERBOSE, true);  // 注意初始化信息的完整性，通过genTicket生成
+        }, initParams, Constants.LogLevel.LOG_LEVEL_DEBUG, true);  // 注意初始化信息的完整性，通过genTicket生成
 
         if (Constants.NuiResultCode.SUCCESS == ret) {
             mInitialized = true;
