@@ -244,6 +244,13 @@ public class WakeupAndSpeechRecognizerActivity extends Activity implements INati
         Log.i(TAG, "result = " + ret);
         if (ret == Constants.NuiResultCode.SUCCESS) {
             mInit = true;
+            String default_kws_info = nui_instance.getParam("kws_default_settings");
+            Log.i(TAG, "Default KWS info:" + default_kws_info);
+            String wakeupWord = extractActiveKeywords(default_kws_info);
+            if (!wakeupWord.isEmpty()) {
+                kwsEdit.setText(wakeupWord);
+                showText(kwsEdit, wakeupWord);
+            }
         } else {
             final String msg_text = Utils.getMsgWithErrorCode(ret, "init");
             ToastText(msg_text, Toast.LENGTH_LONG);
@@ -262,13 +269,14 @@ public class WakeupAndSpeechRecognizerActivity extends Activity implements INati
 
             //参数可根据实际业务进行配置
 //            nls_config.put("enable_inverse_text_normalization", true);
-//            nls_config.put("enable_voice_detection", true);
 //            nls_config.put("customization_id", "test_id");
 //            nls_config.put("vocabulary_id", "test_id");
-//            nls_config.put("max_start_silence", 10000);
-//            nls_config.put("max_end_silence", 800);
             nls_config.put("sample_rate", SAMPLE_RATE);
-//            nls_config.put("sr_format", "opus");
+            nls_config.put("sr_format", "opus");
+
+            // 请不要开启云端vad!!!!
+            // 以下为云端识别vad的设置，由于本地唤醒识别功能由本地vad控制，本地vad参数设置请看genDialogParams()
+            nls_config.put("enable_voice_detection", false);
 
             /*若文档中不包含某些参数，但是此功能支持这个参数，可以用如下万能接口设置参数*/
 //            JSONObject extend_config = new JSONObject();
@@ -286,16 +294,21 @@ public class WakeupAndSpeechRecognizerActivity extends Activity implements INati
             String[] allWakeupWords = SplitWakupWords(kwsEdit.getText().toString());
             if (allWakeupWords.length == 0) {
                 JSONObject wuw = new JSONObject();
-                wuw.put("name", "小云小云");
+                wuw.put("name", defaultWakupWord);
                 // type可设置为main和action，前者指主唤醒词，后者指命令词
                 wuw.put("type", "main");
+                // activation默认true，表示启用此唤醒词。false表示关闭此唤醒词
+//                wuw.put("activation", false);
                 dynamic_wuw.add(wuw);
             } else {
                 for (String part : allWakeupWords) {
                     JSONObject wuw = new JSONObject();
                     wuw.put("name", part.trim());
+//                    wuw.put("threshold1", 0.1); /* 若为资源文件中的唤醒词, 则设置此阈值无效。此阀值仅对自定义唤醒词有效 */
                     // type可设置为main和action，前者指主唤醒词，后者指命令词
                     wuw.put("type", "main");
+                    // activation默认true，表示启用此唤醒词。false表示关闭此唤醒词
+//                    wuw.put("activation", false);
                     dynamic_wuw.add(wuw);
                 }
             }
@@ -480,6 +493,12 @@ public class WakeupAndSpeechRecognizerActivity extends Activity implements INati
             // 注意: 若需要更换appkey和token，可以直接传入参数
 //            dialog_param.put("app_key", "");
 //            dialog_param.put("token", "");
+
+            // 前置vad超时时间，比如唤醒后，2000ms没说话触发超时
+            dialog_param.put("vad_front_timeout", 2000);
+            // vad结尾超时时间，比如人说完一句话后，800ms没说话触发一句话识别完成
+            dialog_param.put("vad_back_timeout", 800);
+
             params = dialog_param.toString();
         } catch (JSONException e) {
             e.printStackTrace();
@@ -552,13 +571,63 @@ public class WakeupAndSpeechRecognizerActivity extends Activity implements INati
         return parts;
     }
 
+    private String extractActiveKeywords(String jsonStr) {
+        if (jsonStr == null || jsonStr.trim().isEmpty()) {
+            return "";
+        }
+        try {
+            JSONObject root = JSON.parseObject(jsonStr);
+            JSONArray wordList = root.getJSONArray("word_list");
+            if (wordList == null) {
+                return "";
+            }
+
+            StringBuilder result = new StringBuilder();
+            for (int i = 0; i < wordList.size(); i++) {
+                JSONObject item = wordList.getJSONObject(i);
+                Boolean activation = item.getBoolean("activation");
+                String name = item.getString("name");
+
+                if (Boolean.TRUE.equals(activation) && name != null) {
+                    String cleanName = name.replaceAll("\\s+", "");
+                    if (!cleanName.isEmpty()) {
+                        if (result.length() > 0) {
+                            result.append(";");
+                        }
+                        result.append(cleanName);
+                    }
+                }
+            }
+            return result.toString();
+
+        } catch (Exception e) {
+            e.printStackTrace();
+            return "";
+        }
+    }
+
     //当回调事件发生时调用
     @Override
     public void onNuiEventCallback(Constants.NuiEvent event, final int resultCode,
                                    final int arg2, KwsResult kwsResult,
                                    AsrResult asrResult) {
         Log.i(TAG, "event=" + event);
-        if (event == Constants.NuiEvent.EVENT_WUW_TRUSTED) {
+        if (event == Constants.NuiEvent.EVENT_VAD_START) {
+            appendText(detailView, "EVENT_VAD_START");
+        } else if (event == Constants.NuiEvent.EVENT_VAD_TIMEOUT) {
+            appendText(detailView, "EVENT_VAD_TIMEOUT");
+            if (mLoopSwitch.isChecked()) {
+                showText(kwsView, "等待唤醒 ...");
+                mHandler.post(new Runnable() {
+                    @Override
+                    public void run() {
+                        nui_instance.startDialog(Constants.VadMode.TYPE_KWS, genDialogParams());
+                    }
+                });
+            }
+        } else if (event == Constants.NuiEvent.EVENT_VAD_END) {
+            appendText(detailView, "EVENT_VAD_END");
+        } else if (event == Constants.NuiEvent.EVENT_WUW_TRUSTED) {
             JSONObject jsonObject = JSON.parseObject(kwsResult.kws);
             String result = jsonObject.getString("word");
             if (!result.isEmpty()) {
